@@ -1,6 +1,6 @@
 
 class EncodedVideoFrameInfo():
-    def __init__(self, codec_type = 0, width = 0, height = 0, frames_per_second = 0, frame_type = 0, rotation = 0, track_id = 0, capture_time_ms = 0, decode_time_ms = 0, uid = 0, stream_type = 0) -> None:
+    def __init__(self, codec_type=0, width=0, height=0, frames_per_second=0, frame_type=0, rotation=0, track_id=0, capture_time_ms=0, decode_time_ms=0, uid=0, stream_type=0) -> None:
         self.codec_type = codec_type
         self.width = width
         self.height = height
@@ -13,8 +13,7 @@ class EncodedVideoFrameInfo():
         self.uid = uid
         self.stream_type = stream_type
 
-class  IVideoEncodedFrameObserver():
 
-    def on_encoded_video_frame(self, agora_video_encoded_frame_observer, uid, image_buffer, length, video_encoded_frame_info:EncodedVideoFrameInfo):
+class IVideoEncodedFrameObserver():
+    def on_encoded_video_frame(self, uid, image_buffer, length, video_encoded_frame_info: EncodedVideoFrameInfo):
         pass
-    
